@@ -146,14 +146,14 @@ class GPSSeries(TimeSeries):
 
         :return: Returns the lat/lon coordinates as list of list for easy visualization using ipyleaflet
         """
-        if not np.array_equal(self.lat, np.array(None)) and not np.array_equal(self.lat, np.array(None)):
-            return [[lat, lon] for lat, lon in zip(self.lat, self.lon)]
+        if np.array_equal(self.lat, np.array(None)) and np.array_equal(self.lat, np.array(None)):
+            logger.warning("Coordinates are empty")
+            return [[]]
         elif len(self.lat) == 0 and len(self.lon) == 0:
             logger.warning("Coordinates are empty")
             return [[]]
         else:
-            logger.warning("Coordinates are empty")
-            return [[]]
+            return [[lat, lon] for lat, lon in zip(self.lat, self.lon)]
 
 
 class PressureSeries(TimeSeries):
